LoadedComputation

Struct LoadedComputation 

pub struct LoadedComputation {
    pub computation_id_reference: i32,
    pub type: i32,
    pub advanced_extension: Option<AdvancedExtension>,
}

Fields

computation_id_reference: i32

The value corresponds to a plan unique number for that datastructure. Any particular computation may be saved only once but it may be loaded multiple times.

type: i32

The type of this computation. While a plan may use COMPUTATION_TYPE_UNKNOWN for all of its types it is recommended to use a more specific type so that the optimization is more portable. The consumer should be able to decide if an unknown type here matches the same unknown type at a different plan and ignore the optimization if they are mismatched.

advanced_extension: Option<AdvancedExtension>

Implementations

Source

impl LoadedComputation

pub fn type(&self) -> ComputationType

Returns the enum value of type, or the default if the field is set to an invalid enum value.

pub fn set_type(&mut self, value: ComputationType)

Sets type to the provided enum value.